/**
* @version   1.12 October 15, 2019
* @author    RocketTheme http://www.rockettheme.com
* @copyright Copyright (C) 2007 - 2019 RocketTheme, LLC
* @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 */

var GantryPill = new Class({
    Implements: [Options, Events],
    options: {
        duration: 400,
        transition: 'quad:out',
        color: '#fff',
        pill: {
            'left': 'fusion-pill-l',
            'right': 'fusion-pill-r'
        }
    },
    initialize: function (a, b) {
        this.el = $$(a)[0] || null;
        if (!this.el) return;
        this.setOptions(b);
        var c = new Element('div', {
            'class': this.options.pill.left
        }).inject(this.el, 'after');
        new Element('div', {
            'class': this.options.pill.right
        }).inject(c);
        this.list = this.el.getElements('li');
        this.active = this.el.getElement('.active');
        this.noActive = false;
        if (!this.active) {
            this.noActive = true;
            this.active = this.list[0];
        }
        if (this.list[0].hasClass('active')) {
            this.defaultColor = this.list[1].getElement('.item').getStyle('color');
        } else {
            this.defaultColor = this.list[0].getElement('.item').getStyle('color');
        }
        this.pillTop = c.getStyle('top').toInt() || 0;
        this.pillBottom = c.getStyle('top').toInt() || 0;
        this.pillMargins = (c.getStyle('margin-left').toInt() + c.getStyle('margin-right').toInt()) || 0;
        this.pillBordersLeftRight = (c.getStyle('border-left-width').toInt() + c.getStyle('border-right-width').toInt()) || 0;
        this.pillBordersTopBottom = (c.getStyle('border-top-width').toInt() + c.getStyle('border-bottom-width').toInt()) || 0;
        this.pillDefaults = {
            'left': this.active.offsetLeft - c.getStyle('border-right-width').toInt(),
            'top': this.active.offsetTop + this.pillTop - this.pillBordersTopBottom,
            'width': this.active.offsetWidth - this.pillMargins - this.pillBordersLeftRight
        };

        this.fx = new Fx.Morph(c, {
            duration: this.options.duration,
            transition: this.options.transition,
            link: 'cancel'
        }).set(this.pillDefaults);

        if (this.noActive) {
            this.fx.set({
                'opacity': 0
            });
            this.pillDefaults.opacity = 0;
        }
        var d = this;
        this.list.addEvents({
            'mouseenter': function () {
                if (!this.fx && d.options.color && !this.hasClass('active')) {
                    this.fx = new Fx.Tween(this.getElement('.item'), {
                        duration: d.options.duration,
                        transition: d.options.transition,
                        link: 'cancel'
                    }).set('color', d.defaultColor);
                }
                if (d.noActive) {
                    if (!d.fx.to || d.fx.to.opacity == 0) {
                        d.fx.set({
                            'left': this.offsetLeft - c.getStyle('border-right-width').toInt(),
                            'top': d.pillDefaults.top = this.offsetTop + d.pillTop - d.pillBordersTopBottom,
                            'width': this.offsetWidth - d.pillMargins - d.pillBordersLeftRight
                        });
                    }
                    d.fx.start({
                        'left': this.offsetLeft - c.getStyle('border-right-width').toInt(),
                        'top': this.offsetTop + d.pillTop - d.pillBordersTopBottom,
                        'width': this.offsetWidth - d.pillMargins,
                        'opacity': 1
                    });
                    if (d.options.color && !this.hasClass('active')) this.fx.start('color', d.options.color);
                } else {
                    d.fx.start({
                        'left': this.offsetLeft - c.getStyle('border-right-width').toInt(),
                        'top': this.offsetTop + d.pillTop - d.pillBordersTopBottom,
                        'width': this.offsetWidth - d.pillMargins
                    });
                    if (d.options.color && !this.hasClass('active')) this.fx.start('color', d.options.color);
                }
            },
            'mouseleave': function () {
                if (d.noActive) {
                    delete d.pillDefaults.left;
                    delete d.pillDefaults.top;
                    delete d.pillDefaults.width;
                }
                d.fx.start(d.pillDefaults);
                d.active.fireEvent('leaving');
                if (this.fx && d.options.color) this.fx.start('color', d.defaultColor);
            }
        })
    }
});
